module REES46
  class Recommender
    RECOMMENDER_TYPES = [:interesting, :also_bought, :similar, :popular, :see_also, :recently_viewed, :buying_now]

    class << self
      RECOMMENDER_TYPES.each do |recommender_type|
        define_method recommender_type do |params = {}|
          recommend(recommender_type, params)
        end
      end

      def recommend(recommender_type, params)
        raise REES46::NotConfiguredError.new('REES46 should be configured first') unless REES46.configured?
        
        result = REES46::Requester.recommend(normalize(params, recommender_type))

        if result.code == 200
          return result.to_a
        else
          return []
        end
      end

      def normalize(params, recommender_type)
        result = params.dup
        result = result.merge(recommender_type: recommender_type)

        [:locations, :categories].each do |key|
          if result[key].present? && result[key].any?
            result[key] = result[key].join(',')
          end
        end

        if params[:cart].present?
          params[:cart].each_with_index do |cart_id, i|
            result["cart[#{i}]"] = cart_id
          end

          result.delete(:cart)
        end

        result
      end
    end
  end
end
