require 'httparty'
require 'timeout'

module REES46
  class Requester
    HOST = 'http://api.rees46.com'
    TIMEOUT = 2

    class << self
      def recommend(params)
        request('recommend', :get, params)
      end

      def push(params)
        request('push', :post, params)
      end

      def generate_ssid(params)
        request('generate_ssid', :get, params)
      end

      def request(path, method, params)
        result = nil

        merged_params = params.merge(shop_id: REES46.configuration.shop_id, ssid: REES46.configuration.session_id, user_id: REES46.configuration.user_id)

        begin
          Timeout::timeout(TIMEOUT) do
            result = if method == :get 
              HTTParty.get("#{HOST}/#{path}", query: merged_params)
            else
              HTTParty.post("#{HOST}/#{path}", body: merged_params)
            end
          end
        rescue Timeout::Error => e
          puts 'REES46 is currently unavailable'
        end

        result
      end
    end
  end
end
