module REES46
  class Tracker
    EVENT_TYPES = [:view, :cart, :remove_from_cart, :purchase, :rate]
    ITEM_ATTRIBUTES = [:item_id, :price, :is_available, :category, :locations, :name, :description, :url, :image_url, :tags]

    class << self
      EVENT_TYPES.each do |event_type|
        define_method event_type do |arguments|
          track(event_type, arguments)
        end
      end

      def track(event_type, arguments)
        raise REES46::NotConfiguredError.new('REES46 should be configured first') unless REES46.configured?

        resp = REES46::Requester.push(normalize(arguments, event_type))
        if resp.code == 500
          puts "REES46: Oops, something gone wrong"
        else
          resp.parsed_response
        end
      end

      def normalize(arguments, event_type)
        result = arguments.dup
        result[:event] = event_type.to_s

        if result[:item].present?
          result[:item].each do |key, value|
            if value.is_a?(Array)
              result["#{key}[0]"] = value.join(',')
            else
              result["#{key}[0]"] = value
            end
          end
          result.delete(:item)
        end

        if result[:items].present?
          result[:items].each_with_index do |item, i|
            item.each do |key, value|
              if value.is_a?(Array)
                result["#{key}[#{i}]"] = value.join(',')
              else
                result["#{key}[#{i}]"] = value
              end
            end
          end
          result.delete(:items)
        end

        result
      end
    end
  end
end
